@@ -115,6 +115,20 @@ class Eaves:
 
     def get_return_type(self, func: Callable) -> Any:
         return func.__annotations__["return"]
+    
+    def check_resize(self, events: list[Event]) -> None:
+        for event in events:
+            if event.type == pygame.VIDEORESIZE:
+                old_surface_saved = self.screen
+                self.res = (event.w, event.h)
+
+                self.screen = display.set_mode(
+                    (event.w, event.h),
+                    pygame.RESIZABLE
+                )
+
+                self.screen.blit(old_surface_saved, (0,0)) # type: ignore
+                del old_surface_saved
 
     def render_text(
         self, font: Font,
@@ -164,6 +178,9 @@ class Eaves:
                 self.running = False
                 break
             
+            if window_type == pygame.RESIZABLE:
+                self.check_resize(events)
+            
             func: Callable = self.handlers[self.current_status]
             _type = func.__annotations__["return"]
             
